summaryrefslogtreecommitdiff
path: root/cogl/cogl-bitmap.h
diff options
context:
space:
mode:
authorRobert Bragg <robert@linux.intel.com>2010-05-28 00:51:40 +0100
committerRobert Bragg <robert@linux.intel.com>2010-06-01 12:20:59 +0100
commit653d1a32542f5be81f136cb51ad1de2d39f88739 (patch)
tree6bc649a27f87003ac751797577006c15bed4d800 /cogl/cogl-bitmap.h
parent817c1cddccf1286e3773ab74a43892484b2bd75f (diff)
downloadcogl-653d1a32542f5be81f136cb51ad1de2d39f88739.tar.gz
bitmap: Remove use of CoglHandle in the CoglBitmap API
This replaces the use of CoglHandle with strongly type CoglBitmap * pointers instead. The only function not converted for now is cogl_is_bitmap which will be done in a later commit.
Diffstat (limited to 'cogl/cogl-bitmap.h')
-rw-r--r--cogl/cogl-bitmap.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/cogl/cogl-bitmap.h b/cogl/cogl-bitmap.h
index f6bce86c..6368841a 100644
--- a/cogl/cogl-bitmap.h
+++ b/cogl/cogl-bitmap.h
@@ -32,6 +32,8 @@
G_BEGIN_DECLS
+typedef struct _CoglBitmap CoglBitmap;
+
/**
* SECTION:cogl-bitmap
* @short_description: Fuctions for loading images
@@ -51,12 +53,12 @@ G_BEGIN_DECLS
* Loads an image file from disk. This function can be safely called from
* within a thread.
*
* Return value: a #CoglHandle to the new loaded image data, or
* %COGL_INVALID_HANDLE if loading the image failed.
*
* Since: 1.0
*/
-CoglHandle
+CoglBitmap *
cogl_bitmap_new_from_file (const char *filename,
GError **error);
@@ -51,12 +53,12 @@ G_BEGIN_DECLS
* within a thread.
*
- * Return value: a #CoglHandle to the new loaded image data, or
- * %COGL_INVALID_HANDLE if loading the image failed.
+ * Return value: a #CoglBitmap to the new loaded image data, or
+ * %NULL if loading the image failed.
*
* Since: 1.0